@@ -6,16 +6,23 @@ from subprocess import Popen, PIPE
 __all__ = ['Test23Support']
 
 class Test23Support(object):
+    def _u2str(self, text):
+        if sys.version < '3':
+            return text.encode(self.env.charset)
+        else:
+            return text
+
     def _b2u(self, text):
         return text.decode(self.env.charset)
-        
+
     def _2unicode(self, text):
         if sys.version < '3':
             return text.decode(self.env.charset)
         else:
             return text
-            
-    def _2str(self, text):  
+
+    #def _2str(self, text):
+    def _mecab_input(self, text):
         if sys.version < '3':
             return text
         else:
@@ -27,6 +34,9 @@ class Test23Support(object):
         else:
             return text.decode(self.env.charset)
 
+    def _mecab_output(self, text):
+        return self._2bytes(text)
+
 
 # full path to MeCab library is required for testing...
 if not os.getenv(MeCab.MECAB_PATH):
@@ -47,7 +57,6 @@ try:
 except StandardError as err:
     raise EnvironmentError(err)
 
-
 '''
 Copyright (c) 2015, Brooke M. Fujita.
 All rights reserved.
