@@ -5,6 +5,8 @@ from .test_binding import TestBinding
 from .test_dictionary import TestDictionary
 from .test_environment import TestMeCabEnv
 from .test_mecab import TestMecab
+from .test_option_parse import TestOptionParse
+from .test_support import TestSupport
 
 def test_suite():
     '''Returns suite of tests for natto-py'''
@@ -13,9 +15,10 @@ def test_suite():
     suite.addTest(TestDictionary)
     suite.addTest(TestMeCabEnv)
     suite.addTest(TestMecab)
+    suite.addTest(TestOptionParse)
+    suite.addTest(TestSupport)
     return suite
 
-
 '''
 Copyright (c) 2015, Brooke M. Fujita.
 All rights reserved.
